@@ -1,9 +1,13 @@
 package Geo::Address::Parser;
 
+use 5.014;
 use strict;
 use warnings;
+
 use Carp;
 use Module::Runtime qw(use_module);
+use Params::Get;
+use Text::Capitalize 'capitalize_title';
 
 =head1 NAME
 
@@ -11,11 +15,11 @@ Geo::Address::Parser - Lightweight country-aware address parser from flat text
 
 =head1 VERSION
 
-Version 0.01
+Version 0.02
 
 =cut
 
-our $VERSION = '0.01';
+our $VERSION = '0.02';
 
 =head1 SYNOPSIS
 
@@ -67,36 +71,50 @@ my %COUNTRY_MODULE = (
 );
 
 sub new {
-    my ($class, %args) = @_;
+	my $class = shift;
 
-    croak "Missing required 'country' parameter" unless $args{country};
+	my $params = Params::Get::get_params('country', \@_);
 
-    my $country = uc $args{country};
-    my $module  = $COUNTRY_MODULE{$country}
-      or croak "Unsupported country: $country";
+	croak "Missing required 'country' parameter" unless $params->{country};
 
-    # Load the appropriate parser module dynamically
-    use_module($module);
+	my $country = uc $params->{'country'};
+	my $module = $COUNTRY_MODULE{$country} or croak "Unsupported country: $country";
 
-    return bless {
-        country => $country,
-        module  => $module,
-    }, $class;
+	# Load the appropriate parser module dynamically
+	use_module($module);
+
+	return bless {
+		country => $country,
+		module => $module,
+	}, $class;
 }
 
-sub parse {
-    my ($self, $text) = @_;
+sub parse
+{
+	my $self = shift;
 
-    croak "No input text provided" unless defined $text;
+	my $params = Params::Get::get_params('text', \@_);
 
-    my $parser = $self->{module};
+	my $text = $params->{'text'};
 
-    my $result = $parser->parse_address($text);
+	croak 'No input text provided' unless defined $text;
 
-    # Add country field to result if not already present
-    $result->{country} //= $self->{country} if $result;
+	my $parser = $self->{module};
 
-    return $result;
+	# Strip extra whitespace
+	$text =~ s/\s+/ /g;
+	$text =~ s/^\s//g;
+	$text =~ s/\s$//g;
+	$text =~ s/\s,/,/g;
+
+	my $result = $parser->parse_address($text);
+
+	# Add country field to result if not already present
+	$result->{country} //= $self->{country} if $result;
+
+	$result->{'name'} = capitalize_title($result->{'name'}) if($result->{'name'});
+
+	return $result;
 }
 
 =head1 LICENCE AND COPYRIGHT
